Function decode_from

pub fn decode_from(bytes: &[u8]) -> Result<Metadata, Error>
Attempt to decode some bytes into Metadata, returning an error if decoding fails.

This is a shortcut for importing codec::Decode and using the implementation of that on Metadata.