This module contains the trait and types used to represent transactions that can be submitted.
Structs
- Default
Payload - A transaction payload containing some generic
CallData. - Validation
Details - Details required to validate the shape of a transaction payload against some metadata.
Traits
- Payload
- This represents a transaction payload that can be submitted to a node.
Functions
- dynamic
- Construct a transaction at runtime; essentially an alias to
DefaultPayload::new()which provides aCompositevalue for the call data.
Type Aliases
- Dynamic
Payload - The type of a payload typically used for dynamic transaction payloads.
- Static
Payload - The payload type used by static codegen.